@@ -3,8 +3,9 @@ from typing import Optional, List
 from enum import IntEnum
 from agricore_sp_models.common_models import OrganicProductionType, ProductGroupJsonDTO, LandRentJsonDTO, LandRentDTO, PolicyJsonDTO, PolicyGroupRelationJsonDTO
 from pydantic import confloat
+from agricore_sp_models import CaseInsensitiveModel
     
-class AgriculturalProduction(BaseModel):
+class AgriculturalProduction(CaseInsensitiveModel):
     id: Optional[int] = None
     farmId: int
     yearId: int
@@ -29,7 +30,7 @@ class AgriculturalProduction(BaseModel):
     # Unit selling price (PVU - [€/unit])
     sellingPrice: float
     
-class AgriculturalProductionDTO(BaseModel):
+class AgriculturalProductionDTO(CaseInsensitiveModel):
     id: Optional[int] = None
     farmId: int
     yearId: int
@@ -54,7 +55,7 @@ class AgriculturalProductionDTO(BaseModel):
     # Unit selling price (PVU - [€/unit])
     sellingPrice: float
     
-class LivestockProduction(BaseModel):
+class LivestockProduction(CaseInsensitiveModel):
     id: Optional[int] = None
     farmId: int
     yearId: int
@@ -92,18 +93,18 @@ class LivestockProduction(BaseModel):
     # Average variable cost per unit of product [€/ton]
     variableCosts: float
 
-class Population(BaseModel):
+class Population(CaseInsensitiveModel):
     id: Optional[int] = None
     description: str
 
-class SyntheticPopulation(BaseModel):
+class SyntheticPopulation(CaseInsensitiveModel):
     id: Optional[int] = None
     populationId: int
     yearId: int
     description: str
     name: str
     
-class Farm(BaseModel):
+class Farm(CaseInsensitiveModel):
     id: Optional[int] = None
     populationId: Optional[int] = None
     lat: int
@@ -120,7 +121,7 @@ class Farm(BaseModel):
     weight_ra: float
     weight_reg: float
         
-class ProductGroup(BaseModel):
+class ProductGroup(CaseInsensitiveModel):
     id: Optional[int] = None
     populationId: Optional[int] = None
     name: str
@@ -130,13 +131,13 @@ class ProductGroup(BaseModel):
     organic: OrganicProductionType
     modelSpecificCategories: List[str]
     
-class FADNProductRelation(BaseModel):
+class FADNProductRelation(CaseInsensitiveModel):
     id: Optional[int] = None
     productGroupId: Optional[int] = None
     fadnProductId: Optional[int] = None
     populationId: Optional[int] = None
 
-class ClosingValue(BaseModel):
+class ClosingValue(CaseInsensitiveModel):
     id: Optional[int] = None
     # Total Area of type Agricultural Land [ha]
     agriculturalLandArea: float
@@ -195,7 +196,7 @@ class ClosingValue(BaseModel):
     farmId: int
     yearId: int
     
-class Policy(BaseModel):
+class Policy(CaseInsensitiveModel):
     id: Optional[int] = None
     policyIdentifier: str
     policyDescription: str
@@ -204,14 +205,14 @@ class Policy(BaseModel):
     economicCompensation:float
     isCoupled: bool
     
-class PolicyProductGroupRelation(BaseModel):
+class PolicyProductGroupRelation(CaseInsensitiveModel):
     id: Optional[int] = None
     productGroupId: int
     policyId: int
     populationId: Optional[int] = None
     economicCompensation:float
 
-class HolderFarmYearData(BaseModel):
+class HolderFarmYearData(CaseInsensitiveModel):
     id: Optional[int] = None
     farmId: Optional[int] = None
     yearId: Optional[int] = None
@@ -221,27 +222,27 @@ class HolderFarmYearData(BaseModel):
     holderSuccessorsAge: int
     holderFamilyMembers: int
     
-class FarmYearSubsidy(BaseModel):
+class FarmYearSubsidy(CaseInsensitiveModel):
     id: Optional[int] = None
     farmId: int
     yearId: int
     policyId: int
     value: float
 
-class FarmYearSubsidyDTO(BaseModel):
+class FarmYearSubsidyDTO(CaseInsensitiveModel):
     farmId: Optional[int] = None
     yearNumber: int
     value: float
     policyIdentifier: str
 
-class HolderInfoDTO(BaseModel):
+class HolderInfoDTO(CaseInsensitiveModel):
     holderAge: int
     holderSuccessorsAge: int
     holderSuccessors: int
     holderFamilyMembers: int
     holderGender: str
 
-class ValueToLPDTO(BaseModel):
+class ValueToLPDTO(CaseInsensitiveModel):
     farmId: int
     yearId: int
     a_0: float
@@ -261,7 +262,7 @@ class ValueToLPDTO(BaseModel):
     agentHolder: Optional[HolderInfoDTO] = None
     agentSubsidies: Optional[List[FarmYearSubsidyDTO]] = None
 
-class CropDataDTO(BaseModel):
+class CropDataDTO(CaseInsensitiveModel):
     # Crop productive Area [ha]
     cropProductiveArea: float
     # Variable Costs per produced unit (CV - [€/ton])
@@ -281,7 +282,7 @@ class CropDataDTO(BaseModel):
     # Number (LSU) of dairy cows
     dairyCows: float
 
-class ValueFromSPDTO(BaseModel):
+class ValueFromSPDTO(CaseInsensitiveModel):
     farmId: int
     # Total Current Assets [€]
     totalCurrentAssets: float
@@ -303,7 +304,7 @@ class ValueFromSPDTO(BaseModel):
     # Subsidies received by the farm
     subsidies: List[FarmYearSubsidyDTO]
 
-class LivestockDTO(BaseModel):
+class LivestockDTO(CaseInsensitiveModel):
     # Number of animals [units]
     numberOfAnimals: float
     # Number of dairy cows [units]
@@ -322,7 +323,7 @@ class AltitudeEnum(IntEnum):
     HILLS = 2
     PLAINS = 3
 
-class ValueToSPDTO(BaseModel):
+class ValueToSPDTO(CaseInsensitiveModel):
     farmCode: int
     holderInfo: Optional[HolderInfoDTO] = None
     cod_RAGR: str
@@ -337,27 +338,27 @@ class ValueToSPDTO(BaseModel):
     greeningSurface: float
     rentedInLands: List[LandRentDTO]
 
-class DataToSPDTO(BaseModel):
+class DataToSPDTO(CaseInsensitiveModel):
     values: List[ValueToSPDTO]
     productGroups: List[ProductGroupJsonDTO]
     policies: List[PolicyJsonDTO]
     policyGroupRelations: List[PolicyGroupRelationJsonDTO]
     farmYearSubsidies: List[FarmYearSubsidyDTO]
 
-class IntermediateValueFromLP(BaseModel):
+class IntermediateValueFromLP(CaseInsensitiveModel):
     farmId: int
     averageHAPrice: float
     previousAgriculturalLand: float
     result: dict
 
-class LandTransaction(BaseModel):
+class LandTransaction(CaseInsensitiveModel):
     productionId: int
     destinationFarmId: int
     yearId: int
     percentage: confloat(ge=0, le=1)
     salePrice: float
 
-class AgroManagementDecisions(BaseModel):
+class AgroManagementDecisions(CaseInsensitiveModel):
     farmId: int
     yearId: int
     # Total Area of type Agricultural Land [ha]
@@ -375,15 +376,16 @@ class AgroManagementDecisions(BaseModel):
     # Boolean to indicate if the farmer is willing to retire and hand over the farm to its successors
     retireAndHandOver: bool
 
-class AgroManagementDecisionFromLP(BaseModel):
+class AgroManagementDecisionFromLP(CaseInsensitiveModel):
     agroManagementDecisions: List[AgroManagementDecisions]
     landTransactions: List[LandTransaction]
     errorList: List[int]
 
-class DataToLPDTO(BaseModel):
+class DataToLPDTO(CaseInsensitiveModel):
     values: List[ValueToLPDTO]
     agriculturalProductions: List[AgriculturalProductionDTO]
     policyGroupRelations: List[PolicyGroupRelationJsonDTO]
     ignoreLP: Optional[bool]
     ignoreLMM: Optional[bool]
+    policies: Optional[List[PolicyJsonDTO]]
 
