@@ -1,6 +1,8 @@
 from pydantic import BaseModel
 from typing import Optional, Any, List
 from enum import IntEnum
+from agricore_sp_models import CaseInsensitiveModel
+
 
 class SimulationStage(IntEnum):
     DATAPREPARATION = 1
@@ -8,18 +10,36 @@ class SimulationStage(IntEnum):
     LANDMARKET = 3
     SHORTPERIOD = 4
     REALISATION = 5
-class SimulationScenario(BaseModel):
+    
+class CoupledCompensationForUIDTO(CaseInsensitiveModel):
+    productGroup: str
+    economicCompensation: float
+    
+class PolicyForUIDTO(CaseInsensitiveModel):
+    populationId: int
+    policyIdentifier: str
+    isCoupled: bool
+    policyDescription: str
+    economicCompensation: float
+    modelLabel: str
+    startYearNumber: int
+    endYearNumber: int
+    coupledCompensations: Optional[List[CoupledCompensationForUIDTO]] = None
+    
+class SimulationScenario(CaseInsensitiveModel):
     id: Optional[int] = None
     populationId: int
     yearId: int
     ignoreLP: Optional[bool]
     ignoreLMM: Optional[bool]
+    compress: Optional[bool]
     yearToContinueFrom: Optional[int] = None
     stageToContinueFrom: Optional[SimulationStage] = None
     shortTermModelBranch: str
     longTermModelBranch: str
     horizon: int
     queueSuffix: Optional[str] = None
+    additionalPolicies: Optional[List[PolicyForUIDTO]] = None
 
 class LogLevel(IntEnum):
     TRACE = 5
@@ -30,7 +50,7 @@ class LogLevel(IntEnum):
     ERROR = 40
     CRITICAL = 50
 
-class LogMessage(BaseModel):
+class LogMessage(CaseInsensitiveModel):
     simulationRunId: int
     timestamp: int
     source: str
@@ -44,7 +64,7 @@ class OverallStatus(IntEnum):
     COMPLETED = 3
     ERROR = 4
     
-class SimulationRun(BaseModel):
+class SimulationRun(CaseInsensitiveModel):
     id: Optional[int] = None
     simulationScenarioId: int
     logMessages: Optional[List[LogMessage]] = None
